Getting started
===============

AWS CDK test Synth package is implemented for helping you to test your AWS CDK code.

The goal is to cover the missing of an `official testing infrastructure <https://docs.aws.amazon.com/cdk/latest/guide/testing.html>`_ for **Python** as exists for **TypeScript** using `Jest <https://jestjs.io/>`_.

It is part of the `educational repositories <https://github.com/pandle/materials>`_ to learn how to write stardard code and common uses of the TDD.

Prerequisites
#############

This package is useful for testing your `AWS CDK <https://docs.aws.amazon.com/cdk/latest/guide/>`_ code, so you probably have everything you need installed already.

Installation
############

If you want to use this package into your code, you can install by python3-pip:

.. code-block:: bash

    pip3 install aws_cdk_test_synth
    python3
    >>> import aws_cdk_test_synth.test_synth as TestSynth
    >>> help(TestSynth)

Read the documentation on `readthedocs <https://aws-cdk-test-synth.readthedocs.io/en/latest/>`_ for

* Usage
* Development

Change Log
##########

See `CHANGELOG.md <https://github.com/bilardi/aws-cdk-test-synth/blob/master/CHANGELOG.md>`_ for details.

License
#######

This package is released under the MIT license.  See `LICENSE <https://github.com/bilardi/aws-cdk-test-synth/blob/master/LICENSE>`_ for details.
